@@ -1,9 +1,8 @@
-mod config;
 mod constants;
 mod download;
 mod executor;
+mod files_tree;
 mod login;
-mod ls;
 mod pipeline_add;
 mod upload;
 
@@ -12,14 +11,14 @@ use std::path::PathBuf;
 use anyhow::Result;
 use clap::{Parser, Subcommand};
 
-use crate::config::ChrsConfig;
 use crate::download::download;
+use crate::files_tree::files_tree;
 use crate::login::get_client::get_client;
-use crate::ls::ls;
 use crate::pipeline_add::{add_pipeline, convert_pipeline};
 use crate::upload::upload;
 use chris::common_types::{CUBEApiUrl, Username};
 use chris::filebrowser::FileBrowserPath;
+use login::config::ChrsConfig;
 
 #[derive(Parser)]
 #[clap(
@@ -207,7 +206,7 @@ async fn main() -> Result<()> {
         }
         Commands::Tree { level, full, path } => {
             let client = get_client(address, username, password, vec![]).await?;
-            ls(&client, &path, full, level).await
+            files_tree(&client, &path, full, level).await
         }
     }
 }
